@@ -222,6 +222,18 @@ public interface Cluster extends Identified {
     Boolean trustedService();
     Boolean haReservation();
 
+    /**
+     * Chipset and BIOS type combination.
+     *
+     * This value is used as default for all virtual machines in the cluster having `biosType` set to `CLUSTER_DEFAULT`.
+     *
+     * @author Shmuel Melamud <smelamud@redhat.com>
+     * @date 28 Aug 2019
+     * @status added
+     * @since 4.4
+     */
+    BiosType biosType();
+
     /**
      * This property has no longer any relevance and has been deprecated. Its default value is true.
      *
@@ -366,9 +378,12 @@ public interface Cluster extends Identified {
      * Up to version 4.1, it was always `iptables`. Since version 4.2, you can choose between `iptables` and `firewalld`.
      * For clusters with a compatibility version of 4.2 and higher, the default firewall type is `firewalld`.
      *
+     * `iptables` is deprecated in cluster version 4.2 and will be removed in a future cluster version.
+     *
      * @author Ondra Machacek <omachace@redhat.com>
      * @author Tahlia Richardson <trichard@redhat.com>
-     * @date 11 Aug 2017
+     * @author Steve Goodman <sgoodman@redhat.com>
+     * @date 26 Nov 2019
      * @status updated_by_docs
      * @since 4.2
      */
@@ -471,7 +486,9 @@ public interface Cluster extends Identified {
     @Link Permission[] permissions();
 
     /**
-     * The name of the https://fedorahosted.org/tuned[tuned] profile
+     * The name of the tuned profile.
+     *
+     * https://fedorahosted.org/tuned[Tuned] profile
      * to set on all the hosts in the cluster. This is not mandatory
      * and relevant only for clusters with Gluster service.
      *
