@@ -16,6 +16,7 @@ limitations under the License.
 
 package services;
 
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.ClusterLevel;
@@ -51,11 +52,13 @@ public interface ClusterLevelsService {
      * </cluster_levels>
      * ----
      *
+     * The order of the returned cluster levels isn't guaranteed.
+     *
      * @author Aleksei Slaikovskii <aslaikov@redhat.com>
      * @date 12 Dec 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         /**
          * Retrieved cluster levels.
          *
