@@ -310,6 +310,16 @@ public interface HostService extends MeasurableService {
          * @status updated_by_docs
          */
         @In Boolean async();
+
+        /**
+         * Indicates if host should be put into maintenance after restart.
+         *
+         * @author Artur Socha <asocha@redhat.com>
+         * @date 10 Sep 19
+         * @since 4.4
+         * @status requires_text
+         */
+        @In Boolean maintenanceAfterRestart();
     }
 
     /**
@@ -430,7 +440,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123"
      * ----
      *
-     * Example of installing a host, using `curl` and JSON, with hosted engine components:
+     * Example of installing a host using `curl` and JSON with hosted engine components:
      *
      * [source,bash]
      * ----
@@ -451,13 +461,14 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123?deploy_hosted_engine=true"
      * ----
      *
-     * IMPORTANT: Since version 4.1.2 of the engine when a host is reinstalled we override the host firewall
+     * IMPORTANT: Since version 4.1.2 of the engine, when a host is reinstalled we override the host firewall
      * definitions by default.
      *
      * @author Oved Ourfali <oourfali@redhat.com>
      * @author Roy Golan <rgolan@redhat.com>
      * @author Megan Lewis <melewis@redhat.com>
-     * @date 17 Oct 17
+     * @author Eli Marcus <emarcus@redhat.com>
+     * @date 17 Jul 2019
      * @status updated_by_docs
      */
     interface Install {
@@ -514,10 +525,11 @@ public interface HostService extends MeasurableService {
             }
         }
         /**
-         * The password of of the `root` user, used to connect to the host via SSH.
+         * The password of the `root` user used to connect to the host via SSH.
          *
          * @author Megan Lewis <melewis@redhat.com>
-         * @date 17 Oct 17
+         * @author Eli Marcus <emarcus@redhat.com>
+         * @date 17 Jul 2019
          * @status updated_by_docs
          */
         @In String rootPassword();
@@ -560,8 +572,8 @@ public interface HostService extends MeasurableService {
         @In Boolean async();
 
         /**
-         * When set to `true` it means this host should also deploy the self-hosted engine components. A missing value
-         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will perform no operation in the
+         * When set to `true` this host will also deploy the self-hosted engine components. A missing value
+         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will not perform any operation in the
          * self-hosted engine area.
          *
          * @author Megan Lewis <melewis@redhat.com>
@@ -571,12 +583,13 @@ public interface HostService extends MeasurableService {
         @In Boolean deployHostedEngine();
 
         /**
-         * When set to `true` it means this host should un-deploy the self-hosted engine components and this host will
-         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy
-         * Omitting this parameter means `false` and will perform no operation in the self-hosted engine area.
+         * When set to `true` this host will un-deploy the self-hosted engine components, and this host will
+         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy.
+         * Omitting this parameter means `false` and will not perform any operation in the self-hosted engine area.
          *
          * @author Megan Lewis <melewis@redhat.com>
-         * @date 17 Oct 17
+         * @author Eli Marcus <emarcus@redhat.com>
+         * @date 17 Jul 2019
          * @status updated_by_docs
          */
         @In Boolean undeployHostedEngine();
@@ -835,29 +848,41 @@ public interface HostService extends MeasurableService {
     interface Upgrade {
 
         @InputDetail
+        /**
+         * This method is no longer relevant, since Vintage Node is no longer supported, and has been deprecated.
+         *
+         * @author Dana Elfassy <delfassy@redhat.com>
+         * @author Eli Marcus <emarcus@redhat.com>
+         * @date 17 Jul 2019
+         * @status updated_by_docs
+
+         */
+        @Deprecated
         default void inputDetail() {
             optional(image());
         }
 
         /**
-         * The image parameter specifies path to image, which is used for upgrade. This parameter is used only to
-         * upgrade Vintage Node hosts and it is not relevant for other hosts types.
+         * This property is no longer relevant, since Vintage Node is no longer supported, and has been deprecated.
          *
-         * @author Megan Lewis <melewis@redhat.com>
-         * @date 17 Oct 17
+         * @author Dana Elfassy <delfassy@redhat.com>
+         * @author Eli Marcus <emarcus@redhat.com>
+         * @date 21 Aug 2019
          * @status updated_by_docs
          */
+        @Deprecated
         @In String image();
 
         /**
-         * Indicates if the host should be rebooted after upgrade.
+         * Indicates if the host should be rebooted after the upgrade.
          * By default the host is rebooted.
          *
-         * NOTE: This parameter is ignored for {hypervisor-name}, which is always rebooted after upgrade.
+         * NOTE: This parameter is ignored for {hypervisor-name}, which is always rebooted after the upgrade.
          *
          * @author Ondra Machacek <omachace@redhat.com>
          * @author Byron Gravenorst <bgraveno@redhat.com>
-         * @date 20 Oct 2017
+         * @author Eli Marcus <emarcus@redhat.com>
+         * @date 17 Jul 2019
          * @status updated_by_docs
          * @since 4.2
          */
@@ -871,6 +896,19 @@ public interface HostService extends MeasurableService {
          * @status updated_by_docs
          */
         @In Boolean async();
+
+	/**
+	 * Upgrade timeout.
+	 *
+	 * The maximum time to wait for upgrade to finish in minutes.
+	 * Default value is specified by `ANSIBLE_PLAYBOOK_EXEC_DEFAULT_TIMEOUT` configration option.
+	 *
+	 * @author Ondra Machacek <omacahce@redhat.com>
+	 * @date 29 Aug 2019
+	 * @status added
+	 * @since 4.3.6
+	 */
+	@In Integer timeout();
     }
 
     /**
@@ -933,6 +971,18 @@ public interface HostService extends MeasurableService {
      * @status updated_by_docs
      */
     interface Remove {
+
+        /**
+         * Indicates that the host should be removed even if it is non-responsive,
+         * or if it is part of a Gluster Storage cluster and has volume bricks on it.
+         *
+         * @author Ori Liel<oliel@redhat.com>
+         * @date 17 Jan 2019
+         * @status added
+         * @since 4.3
+         */
+        @In Boolean force();
+
         /**
          * Indicates if the remove should be performed asynchronously.
          *
@@ -1033,7 +1083,7 @@ public interface HostService extends MeasurableService {
      * <ip address="192.168.122.10" netmask="255.255.255.0"/>
      * ----
      *
-     * Using the Python SDK the same can be done with the following code:
+     * The same thing can be done using the Python SDK with the following code:
      *
      * [source,python]
      * ----
@@ -1118,8 +1168,10 @@ public interface HostService extends MeasurableService {
      *
      * @author Megan Lewis <melewis@redhat.com>
      * @author Eitan Raviv <eraviv@redhat.com>
-     * @date 03 Dec 2018
-     * @status added
+     * @author Eli Marcus <emarcus@redhat.com>
+     * @date 17 Jul 2019
+     * @status updated_by_docs
+
      */
     interface SetupNetworks {
         @InputDetail
@@ -1223,6 +1275,57 @@ public interface HostService extends MeasurableService {
         @In Boolean async();
     }
 
+
+    /**
+     * Copy the network configuration of the specified host to current host.
+     *
+     * To copy networks from another host, send a request like this:
+     *
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/hosts/123/copyhostnetworks
+     * ----
+     *
+     * With a request body like this:
+     *
+     * [source,xml]
+     * ----
+     * <action>
+     *    <sourceHost id="456" />
+     * </action>
+     * ----
+     *
+     * @author Ales Musil <amusil@redhat.com>
+     * @date 15 Oct 2019
+     * @status added
+     * @since 4.4
+     */
+    interface CopyHostNetworks {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(sourceHost().id());
+        }
+
+        /**
+         * The host to copy networks from.
+         *
+         * @author Ales Musil <amusil@redhat.com>
+         * @date 15 Oct 2019
+         * @status added
+         */
+        @In Host sourceHost();
+
+        /**
+         * Indicates if the action should be performed asynchronously.
+         *
+         * @author Ales Musil <amusil@redhat.com>
+         * @date 15 Oct 2019
+         * @status added
+         */
+        @In Boolean async();
+    }
+
+
     /**
      * A reference to the host permission service.
      * Use this service to manage permissions on the host object.
