@@ -173,7 +173,7 @@ public interface Network extends Identified {
      */
     Boolean profileRequired();
 
-    /*
+    /**
      * The DNS resolver configuration will be reported when retrieving the network using GET.
      * It is optional both when creating a new network or updating existing one.
      *
@@ -185,6 +185,18 @@ public interface Network extends Identified {
      */
     DnsResolverConfiguration dnsResolverConfiguration();
 
+    /**
+     * The name of the network used on the host. This alternative name is automatically generated by VDSM when
+     * the network name is found unsuitable to serve as a bridge name on the host. Unsuitable names contain spaces,
+     * special characters or are longer than 15 characters and are replaced with a UUID on the host.
+     * This parameter is read-only. Setting it will have no effect.
+     *
+     * @author Andrej Cernek <acernek@redhat.com>
+     * @date 17 Dec 2019
+     * @status added
+     */
+    String vdsmName();
+
     /**
      * A reference to the data center that the network is a member of.
      *
