@@ -17,11 +17,15 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.GraphicsConsole;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+
 @Service
 @Area("Virtualization")
 public interface TemplateGraphicsConsolesService {
@@ -34,6 +38,10 @@ public interface TemplateGraphicsConsolesService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(console().protocol());
+        }
         @In @Out GraphicsConsole console();
     }
 
@@ -46,7 +54,7 @@ public interface TemplateGraphicsConsolesService {
      * @date 31 Oct 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
 
         /**
          * The list of graphics consoles of the template.
