@@ -16,6 +16,7 @@ limitations under the License.
 
 package services.gluster;
 
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -64,7 +65,12 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface Activate {
+    interface Activate { //TODO: check live documentation supported. 
+//      @InputDetail
+//      default void inputDetail() {
+//          mandatory(bricks()[COLLECTION].name());
+//      }
+
         /**
          * The list of bricks that need to be re-activated.
          *
@@ -110,7 +116,12 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface Add {
+    interface Add { //TODO: special case - array as primary input, check if 'live documentation' supports this
+//        @InputDetail
+//        default void inputDetail() {
+//            mandatory(bricks()[COLLECTION].brickDir());
+//            mandatory(bricks()[COLLECTION].serverId());
+//        }
         /**
          * The list of bricks to be added to the volume
          *
@@ -175,7 +186,7 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out GlusterBrick[] bricks();
 
         /**
@@ -219,7 +230,11 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface Migrate {
+    interface Migrate { //TODO: check live documentation supported.
+//        @InputDetail
+//        default void inputDetail() {
+//            mandatory(bricks()[COLLECTION].name());
+//        }
         /**
          * List of bricks for which data migration needs to be started.
          *
@@ -265,7 +280,11 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface Remove {
+    interface Remove { //TODO: live documetation does not support paramters in 'remove'
+//        @InputDetail
+//        default void inputDetail() {
+//            mandatory(bricks--collection().id());
+//        }
         /**
          * The list of bricks to be removed
          */
@@ -315,7 +334,11 @@ public interface GlusterBricksService {
      * @date 12 Dec 2016
      * @status added
      */
-    interface StopMigrate {
+    interface StopMigrate { //TODO: check that live documentation is supported
+//        @InputDetail
+//        default void inputDetail() {
+//            mandatory(bricks()[COLLECTION].name());
+//        }
         /**
          * List of bricks for which data migration needs to be stopped. This list should match the arguments passed to
          * <<services/gluster_bricks/methods/migrate, migrate>>.
