@@ -17,6 +17,7 @@ limitations under the License.
 package services.gluster;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
@@ -25,7 +26,16 @@ import types.GlusterHook;
 @Service
 @Area("Gluster")
 public interface GlusterHooksService {
-    interface List {
+    /**
+     * Returns the list of hooks.
+     *
+     * The order of the returned list of hooks isn't guaranteed.
+     *
+     * @author Juan Hernandez <juan.hernandez@redhat.com>
+     * @date 15 Apr 2017
+     * @status added
+     */
+    interface List extends Follow {
         @Out GlusterHook[] hooks();
 
         /**
