@@ -58,6 +58,7 @@ import org.ovirt.engine.sdk4.types.Usb;
 import org.ovirt.engine.sdk4.types.Version;
 import org.ovirt.engine.sdk4.types.VirtioScsi;
 import org.ovirt.engine.sdk4.types.Vm;
+import org.ovirt.engine.sdk4.types.VmPlacementPolicy;
 import org.ovirt.engine.sdk4.types.VmStorageErrorResumeBehaviour;
 import org.ovirt.engine.sdk4.types.VmType;
 import org.ovirt.engine.sdk4.types.Watchdog;
@@ -93,11 +94,13 @@ public class InstanceTypeBuilder {
     private MemoryPolicy memoryPolicy;
     private MigrationOptions migration;
     private BigInteger migrationDowntime;
+    private Boolean multiQueuesEnabled;
     private String name;
     private List<Nic> nics;
     private String origin;
     private OperatingSystem os;
     private List<Permission> permissions;
+    private VmPlacementPolicy placementPolicy;
     private Quota quota;
     private RngDevice rngDevice;
     private SerialNumber serialNumber;
@@ -665,6 +668,17 @@ public class InstanceTypeBuilder {
     }
     
     
+    public InstanceTypeBuilder multiQueuesEnabled(boolean newMultiQueuesEnabled) {
+        multiQueuesEnabled = Boolean.valueOf(newMultiQueuesEnabled);
+        return this;
+    }
+    
+    public InstanceTypeBuilder multiQueuesEnabled(Boolean newMultiQueuesEnabled) {
+        multiQueuesEnabled = newMultiQueuesEnabled;
+        return this;
+    }
+    
+    
     public InstanceTypeBuilder name(String newName) {
         name = newName;
         return this;
@@ -763,6 +777,22 @@ public class InstanceTypeBuilder {
     }
     
     
+    public InstanceTypeBuilder placementPolicy(VmPlacementPolicy newPlacementPolicy) {
+        placementPolicy = newPlacementPolicy;
+        return this;
+    }
+    
+    public InstanceTypeBuilder placementPolicy(VmPlacementPolicyBuilder newPlacementPolicy) {
+        if (newPlacementPolicy == null) {
+            placementPolicy = null;
+        }
+        else {
+            placementPolicy = newPlacementPolicy.build();
+        }
+        return this;
+    }
+    
+    
     public InstanceTypeBuilder quota(Quota newQuota) {
         quota = newQuota;
         return this;
@@ -1103,11 +1133,13 @@ public class InstanceTypeBuilder {
         container.memoryPolicy(memoryPolicy);
         container.migration(migration);
         container.migrationDowntime(migrationDowntime);
+        container.multiQueuesEnabled(multiQueuesEnabled);
         container.name(name);
         container.nics(nics);
         container.origin(origin);
         container.os(os);
         container.permissions(permissions);
+        container.placementPolicy(placementPolicy);
         container.quota(quota);
         container.rngDevice(rngDevice);
         container.serialNumber(serialNumber);
