@@ -31,9 +31,12 @@ public class OpenStackNetworkProviderContainer extends OpenStackProviderContaine
     private Boolean autoSync;
     private String externalPluginType;
     private NetworkPluginType pluginType;
+    private String projectDomainName;
+    private String projectName;
     private Boolean readOnly;
     private OpenStackNetworkProviderType type;
     private Boolean unmanaged;
+    private String userDomainName;
     private List<Certificate> certificates;
     private List<OpenStackNetwork> networks;
     private List<OpenStackSubnet> subnets;
@@ -90,6 +93,30 @@ public class OpenStackNetworkProviderContainer extends OpenStackProviderContaine
         return pluginType != null;
     }
     
+    public String projectDomainName() {
+        return projectDomainName;
+    }
+    
+    public void projectDomainName(String newProjectDomainName) {
+        projectDomainName = newProjectDomainName;
+    }
+    
+    public boolean projectDomainNamePresent() {
+        return projectDomainName != null;
+    }
+    
+    public String projectName() {
+        return projectName;
+    }
+    
+    public void projectName(String newProjectName) {
+        projectName = newProjectName;
+    }
+    
+    public boolean projectNamePresent() {
+        return projectName != null;
+    }
+    
     public boolean readOnly() {
         return readOnly;
     }
@@ -134,6 +161,18 @@ public class OpenStackNetworkProviderContainer extends OpenStackProviderContaine
         return unmanaged != null;
     }
     
+    public String userDomainName() {
+        return userDomainName;
+    }
+    
+    public void userDomainName(String newUserDomainName) {
+        userDomainName = newUserDomainName;
+    }
+    
+    public boolean userDomainNamePresent() {
+        return userDomainName != null;
+    }
+    
     public List<Certificate> certificates() {
         return makeUnmodifiableList(certificates);
     }
