@@ -47,6 +47,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     }
     
     private class AddRequestImpl extends BaseRequest<AddRequest, AddResponse> implements AddRequest {
+        private Boolean activate;
+        public AddRequest activate(Boolean activate) {
+            this.activate = activate;
+            return this;
+        }
+        
         private Boolean deployHostedEngine;
         public AddRequest deployHostedEngine(Boolean deployHostedEngine) {
             this.deployHostedEngine = deployHostedEngine;
@@ -74,6 +80,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             HttpPost request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (activate != null) {
+                    uriBuilder.addParameter("activate", XmlWriter.renderBoolean(activate));
+                }
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
@@ -166,6 +175,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             return this;
         }
         
+        private Boolean checkVmsInAffinityClosure;
+        public ListRequest checkVmsInAffinityClosure(Boolean checkVmsInAffinityClosure) {
+            this.checkVmsInAffinityClosure = checkVmsInAffinityClosure;
+            return this;
+        }
+        
         private Boolean filter;
         public ListRequest filter(Boolean filter) {
             this.filter = filter;
@@ -194,6 +209,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             return this;
         }
         
+        private String migrationTargetOf;
+        public ListRequest migrationTargetOf(String migrationTargetOf) {
+            this.migrationTargetOf = migrationTargetOf;
+            return this;
+        }
+        
         private String search;
         public ListRequest search(String search) {
             this.search = search;
@@ -210,6 +231,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 if (caseSensitive != null) {
                     uriBuilder.addParameter("case_sensitive", XmlWriter.renderBoolean(caseSensitive));
                 }
+                if (checkVmsInAffinityClosure != null) {
+                    uriBuilder.addParameter("check_vms_in_affinity_closure", XmlWriter.renderBoolean(checkVmsInAffinityClosure));
+                }
                 if (filter != null) {
                     uriBuilder.addParameter("filter", XmlWriter.renderBoolean(filter));
                 }
@@ -219,6 +243,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
                 if (max != null) {
                     uriBuilder.addParameter("max", XmlWriter.renderInteger(max));
                 }
+                if (migrationTargetOf != null) {
+                    uriBuilder.addParameter("migration_target_of", XmlWriter.renderString(migrationTargetOf));
+                }
                 if (search != null) {
                     uriBuilder.addParameter("search", XmlWriter.renderString(search));
                 }
@@ -283,6 +310,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     }
     
     private class AddUsingRootPasswordRequestImpl extends BaseRequest<AddUsingRootPasswordRequest, AddUsingRootPasswordResponse> implements AddUsingRootPasswordRequest {
+        private Boolean activate;
+        public AddUsingRootPasswordRequest activate(Boolean activate) {
+            this.activate = activate;
+            return this;
+        }
+        
         private Boolean deployHostedEngine;
         public AddUsingRootPasswordRequest deployHostedEngine(Boolean deployHostedEngine) {
             this.deployHostedEngine = deployHostedEngine;
@@ -310,6 +343,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             HttpPost request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (activate != null) {
+                    uriBuilder.addParameter("activate", XmlWriter.renderBoolean(activate));
+                }
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
@@ -390,6 +426,12 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
     }
     
     private class AddUsingSshRequestImpl extends BaseRequest<AddUsingSshRequest, AddUsingSshResponse> implements AddUsingSshRequest {
+        private Boolean activate;
+        public AddUsingSshRequest activate(Boolean activate) {
+            this.activate = activate;
+            return this;
+        }
+        
         private Boolean deployHostedEngine;
         public AddUsingSshRequest deployHostedEngine(Boolean deployHostedEngine) {
             this.deployHostedEngine = deployHostedEngine;
@@ -417,6 +459,9 @@ public class HostsServiceImpl extends ServiceImpl implements HostsService {
             HttpPost request = null;
             try {
                 URIBuilder uriBuilder = new URIBuilder(getConnection().getUrl() + getPath());
+                if (activate != null) {
+                    uriBuilder.addParameter("activate", XmlWriter.renderBoolean(activate));
+                }
                 if (deployHostedEngine != null) {
                     uriBuilder.addParameter("deploy_hosted_engine", XmlWriter.renderBoolean(deployHostedEngine));
                 }
