@@ -70,6 +70,12 @@ public interface HostService extends MeasurableService {
      * This action also accepts an optional cluster element to define the target cluster for this host.
      */
     public interface ApproveRequest extends Request<ApproveRequest, ApproveResponse> {
+        /**
+         * When set to 'true', this host will be activated after its approval completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its approval. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after approval.
+         */
+        ApproveRequest activate(Boolean activate);
         /**
          * Indicates if the approval should be performed asynchronously.
          */
@@ -124,6 +130,12 @@ public interface HostService extends MeasurableService {
      * ----
      * <action/>
      * ----
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     public interface CommitNetConfigRequest extends Request<CommitNetConfigRequest, CommitNetConfigResponse> {
         /**
@@ -155,6 +167,12 @@ public interface HostService extends MeasurableService {
      * ----
      * <action/>
      * ----
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     public interface CommitNetConfigResponse extends Response {
     }
@@ -182,9 +200,89 @@ public interface HostService extends MeasurableService {
      * ----
      * <action/>
      * ----
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     CommitNetConfigRequest commitNetConfig();
     
+    /**
+     * Copy the network configuration of the specified host to current host.
+     * 
+     * To copy networks from another host, send a request like this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/hosts/123/copyhostnetworks
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *    <sourceHost id="456" />
+     * </action>
+     * ----
+     */
+    public interface CopyHostNetworksRequest extends Request<CopyHostNetworksRequest, CopyHostNetworksResponse> {
+        /**
+         * Indicates if the action should be performed asynchronously.
+         */
+        CopyHostNetworksRequest async(Boolean async);
+        CopyHostNetworksRequest sourceHost(Host sourceHost);
+        /**
+         * The host to copy networks from.
+         */
+        CopyHostNetworksRequest sourceHost(HostBuilder sourceHost);
+    }
+    
+    /**
+     * Copy the network configuration of the specified host to current host.
+     * 
+     * To copy networks from another host, send a request like this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/hosts/123/copyhostnetworks
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *    <sourceHost id="456" />
+     * </action>
+     * ----
+     */
+    public interface CopyHostNetworksResponse extends Response {
+    }
+    
+    /**
+     * Copy the network configuration of the specified host to current host.
+     * 
+     * To copy networks from another host, send a request like this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/hosts/123/copyhostnetworks
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *    <sourceHost id="456" />
+     * </action>
+     * ----
+     */
+    CopyHostNetworksRequest copyHostNetworks();
+    
     /**
      * Deactivates the host to perform maintenance tasks.
      */
@@ -271,6 +369,10 @@ public interface HostService extends MeasurableService {
          */
         FenceRequest async(Boolean async);
         FenceRequest fenceType(String fenceType);
+        /**
+         * Indicates if host should be put into maintenance after restart.
+         */
+        FenceRequest maintenanceAfterRestart(Boolean maintenanceAfterRestart);
     }
     
     /**
@@ -485,7 +587,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123"
      * ----
      * 
-     * Example of installing a host, using `curl` and JSON, with hosted engine components:
+     * Example of installing a host using `curl` and JSON with hosted engine components:
      * 
      * [source,bash]
      * ----
@@ -506,17 +608,23 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123?deploy_hosted_engine=true"
      * ----
      * 
-     * IMPORTANT: Since version 4.1.2 of the engine when a host is reinstalled we override the host firewall
+     * IMPORTANT: Since version 4.1.2 of the engine, when a host is reinstalled we override the host firewall
      * definitions by default.
      */
     public interface InstallRequest extends Request<InstallRequest, InstallResponse> {
+        /**
+         * When set to 'true', this host will be activated after its installation completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its installation. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after install.
+         */
+        InstallRequest activate(Boolean activate);
         /**
          * Indicates if the installation should be performed asynchronously.
          */
         InstallRequest async(Boolean async);
         /**
-         * When set to `true` it means this host should also deploy the self-hosted engine components. A missing value
-         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will perform no operation in the
+         * When set to `true` this host will also deploy the self-hosted engine components. A missing value
+         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will not perform any operation in the
          * self-hosted engine area.
          */
         InstallRequest deployHostedEngine(Boolean deployHostedEngine);
@@ -531,7 +639,7 @@ public interface HostService extends MeasurableService {
          */
         InstallRequest image(String image);
         /**
-         * The password of of the `root` user, used to connect to the host via SSH.
+         * The password of the `root` user used to connect to the host via SSH.
          */
         InstallRequest rootPassword(String rootPassword);
         InstallRequest ssh(Ssh ssh);
@@ -540,9 +648,9 @@ public interface HostService extends MeasurableService {
          */
         InstallRequest ssh(SshBuilder ssh);
         /**
-         * When set to `true` it means this host should un-deploy the self-hosted engine components and this host will
-         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy
-         * Omitting this parameter means `false` and will perform no operation in the self-hosted engine area.
+         * When set to `true` this host will un-deploy the self-hosted engine components, and this host will
+         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy.
+         * Omitting this parameter means `false` and will not perform any operation in the self-hosted engine area.
          */
         InstallRequest undeployHostedEngine(Boolean undeployHostedEngine);
     }
@@ -575,7 +683,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123"
      * ----
      * 
-     * Example of installing a host, using `curl` and JSON, with hosted engine components:
+     * Example of installing a host using `curl` and JSON with hosted engine components:
      * 
      * [source,bash]
      * ----
@@ -596,7 +704,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123?deploy_hosted_engine=true"
      * ----
      * 
-     * IMPORTANT: Since version 4.1.2 of the engine when a host is reinstalled we override the host firewall
+     * IMPORTANT: Since version 4.1.2 of the engine, when a host is reinstalled we override the host firewall
      * definitions by default.
      */
     public interface InstallResponse extends Response {
@@ -630,7 +738,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123"
      * ----
      * 
-     * Example of installing a host, using `curl` and JSON, with hosted engine components:
+     * Example of installing a host using `curl` and JSON with hosted engine components:
      * 
      * [source,bash]
      * ----
@@ -651,7 +759,7 @@ public interface HostService extends MeasurableService {
      * "https://engine.example.com/ovirt-engine/api/hosts/123?deploy_hosted_engine=true"
      * ----
      * 
-     * IMPORTANT: Since version 4.1.2 of the engine when a host is reinstalled we override the host firewall
+     * IMPORTANT: Since version 4.1.2 of the engine, when a host is reinstalled we override the host firewall
      * definitions by default.
      */
     InstallRequest install();
@@ -864,6 +972,11 @@ public interface HostService extends MeasurableService {
          * Indicates if the remove should be performed asynchronously.
          */
         RemoveRequest async(Boolean async);
+        /**
+         * Indicates that the host should be removed even if it is non-responsive,
+         * or if it is part of a Gluster Storage cluster and has volume bricks on it.
+         */
+        RemoveRequest force(Boolean force);
     }
     
     /**
@@ -1001,7 +1114,7 @@ public interface HostService extends MeasurableService {
      * <ip address="192.168.122.10" netmask="255.255.255.0"/>
      * ----
      * 
-     * Using the Python SDK the same can be done with the following code:
+     * The same thing can be done using the Python SDK with the following code:
      * 
      * [source,python]
      * ----
@@ -1076,6 +1189,12 @@ public interface HostService extends MeasurableService {
      * 
      * IMPORTANT: To make sure that the network configuration has been saved in the host, and that it will be applied
      * when the host is rebooted, remember to call <<services/host/methods/commit_net_config, commitnetconfig>>.
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     public interface SetupNetworksRequest extends Request<SetupNetworksRequest, SetupNetworksResponse> {
         /**
@@ -1083,6 +1202,15 @@ public interface HostService extends MeasurableService {
          */
         SetupNetworksRequest async(Boolean async);
         SetupNetworksRequest checkConnectivity(Boolean checkConnectivity);
+        /**
+         * Specifies whether to automatically save the configuration in the {hypervisor-name} upon completing
+         * the setup and re-establishing connectivity between the {hypervisor-name} and {engine-name},
+         * and without waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>>
+         * request.
+         * The default value is `false`, which means that the configuration will not be
+         * saved automatically.
+         */
+        SetupNetworksRequest commitOnSuccess(Boolean commitOnSuccess);
         SetupNetworksRequest connectivityTimeout(Integer connectivityTimeout);
         SetupNetworksRequest connectivityTimeout(Long connectivityTimeout);
         SetupNetworksRequest connectivityTimeout(BigInteger connectivityTimeout);
@@ -1205,7 +1333,7 @@ public interface HostService extends MeasurableService {
      * <ip address="192.168.122.10" netmask="255.255.255.0"/>
      * ----
      * 
-     * Using the Python SDK the same can be done with the following code:
+     * The same thing can be done using the Python SDK with the following code:
      * 
      * [source,python]
      * ----
@@ -1280,6 +1408,12 @@ public interface HostService extends MeasurableService {
      * 
      * IMPORTANT: To make sure that the network configuration has been saved in the host, and that it will be applied
      * when the host is rebooted, remember to call <<services/host/methods/commit_net_config, commitnetconfig>>.
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     public interface SetupNetworksResponse extends Response {
     }
@@ -1374,7 +1508,7 @@ public interface HostService extends MeasurableService {
      * <ip address="192.168.122.10" netmask="255.255.255.0"/>
      * ----
      * 
-     * Using the Python SDK the same can be done with the following code:
+     * The same thing can be done using the Python SDK with the following code:
      * 
      * [source,python]
      * ----
@@ -1449,6 +1583,12 @@ public interface HostService extends MeasurableService {
      * 
      * IMPORTANT: To make sure that the network configuration has been saved in the host, and that it will be applied
      * when the host is rebooted, remember to call <<services/host/methods/commit_net_config, commitnetconfig>>.
+     * 
+     * IMPORTANT: Since {engine-name} 4.3, it is possible to also specify `commit_on_success` in
+     * the <<services/host/methods/setup_networks, setupnetworks>> request, in which case the new
+     * configuration is automatically saved in the {hypervisor-name} upon completing the setup and
+     * re-establishing connectivity between the {hypervisor-name} and {engine-name}, and without
+     * waiting for a separate <<services/host/methods/commit_net_config, commitnetconfig>> request.
      */
     SetupNetworksRequest setupNetworks();
     
@@ -1623,17 +1763,37 @@ public interface HostService extends MeasurableService {
          */
         UpgradeRequest async(Boolean async);
         /**
-         * The image parameter specifies path to image, which is used for upgrade. This parameter is used only to
-         * upgrade Vintage Node hosts and it is not relevant for other hosts types.
+         * This property is no longer relevant, since Vintage Node is no longer supported, and has been deprecated.
          */
         UpgradeRequest image(String image);
         /**
-         * Indicates if the host should be rebooted after upgrade.
+         * Indicates if the host should be rebooted after the upgrade.
          * By default the host is rebooted.
          * 
-         * NOTE: This parameter is ignored for {hypervisor-name}, which is always rebooted after upgrade.
+         * NOTE: This parameter is ignored for {hypervisor-name}, which is always rebooted after the upgrade.
          */
         UpgradeRequest reboot(Boolean reboot);
+        /**
+         * Upgrade timeout.
+         * 
+         * The maximum time to wait for upgrade to finish in minutes.
+         * Default value is specified by `ANSIBLE_PLAYBOOK_EXEC_DEFAULT_TIMEOUT` configration option.
+         */
+        UpgradeRequest timeout(Integer timeout);
+        /**
+         * Upgrade timeout.
+         * 
+         * The maximum time to wait for upgrade to finish in minutes.
+         * Default value is specified by `ANSIBLE_PLAYBOOK_EXEC_DEFAULT_TIMEOUT` configration option.
+         */
+        UpgradeRequest timeout(Long timeout);
+        /**
+         * Upgrade timeout.
+         * 
+         * The maximum time to wait for upgrade to finish in minutes.
+         * Default value is specified by `ANSIBLE_PLAYBOOK_EXEC_DEFAULT_TIMEOUT` configration option.
+         */
+        UpgradeRequest timeout(BigInteger timeout);
     }
     
     /**
@@ -1673,11 +1833,13 @@ public interface HostService extends MeasurableService {
      */
     UpgradeCheckRequest upgradeCheck();
     
-    /**
-     * Approve the specified host to be added to the engine by using the root password (deprecated verb). This
-     * occurs when the host registers itself with the engine.
-     */
     public interface ApproveUsingRootPasswordRequest extends Request<ApproveUsingRootPasswordRequest, ApproveUsingRootPasswordResponse> {
+        /**
+         * When set to 'true', this host will be activated after its approval completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its approval. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after approval.
+         */
+        ApproveUsingRootPasswordRequest activate(Boolean activate);
         /**
          * Indicates if the approval should be performed asynchronously.
          */
@@ -1694,17 +1856,9 @@ public interface HostService extends MeasurableService {
         ApproveUsingRootPasswordRequest host(HostBuilder host);
     }
     
-    /**
-     * Approve the specified host to be added to the engine by using the root password (deprecated verb). This
-     * occurs when the host registers itself with the engine.
-     */
     public interface ApproveUsingRootPasswordResponse extends Response {
     }
     
-    /**
-     * Approve the specified host to be added to the engine by using the root password (deprecated verb). This
-     * occurs when the host registers itself with the engine.
-     */
     ApproveUsingRootPasswordRequest approveUsingRootPassword();
     
     /**
@@ -1712,13 +1866,19 @@ public interface HostService extends MeasurableService {
      * password. This has been deprecated.
      */
     public interface InstallUsingRootPasswordRequest extends Request<InstallUsingRootPasswordRequest, InstallUsingRootPasswordResponse> {
+        /**
+         * When set to 'true', this host will be activated after its installation completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its installation. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after install.
+         */
+        InstallUsingRootPasswordRequest activate(Boolean activate);
         /**
          * Indicates if the installation should be performed asynchronously.
          */
         InstallUsingRootPasswordRequest async(Boolean async);
         /**
-         * When set to `true` it means this host should also deploy the self-hosted engine components. A missing value
-         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will perform no operation in the
+         * When set to `true` this host will also deploy the self-hosted engine components. A missing value
+         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will not perform any operation in the
          * self-hosted engine area.
          */
         InstallUsingRootPasswordRequest deployHostedEngine(Boolean deployHostedEngine);
@@ -1733,7 +1893,7 @@ public interface HostService extends MeasurableService {
          */
         InstallUsingRootPasswordRequest image(String image);
         /**
-         * The password of of the `root` user, used to connect to the host via SSH.
+         * The password of the `root` user used to connect to the host via SSH.
          */
         InstallUsingRootPasswordRequest rootPassword(String rootPassword);
         InstallUsingRootPasswordRequest ssh(Ssh ssh);
@@ -1742,9 +1902,9 @@ public interface HostService extends MeasurableService {
          */
         InstallUsingRootPasswordRequest ssh(SshBuilder ssh);
         /**
-         * When set to `true` it means this host should un-deploy the self-hosted engine components and this host will
-         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy
-         * Omitting this parameter means `false` and will perform no operation in the self-hosted engine area.
+         * When set to `true` this host will un-deploy the self-hosted engine components, and this host will
+         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy.
+         * Omitting this parameter means `false` and will not perform any operation in the self-hosted engine area.
          */
         InstallUsingRootPasswordRequest undeployHostedEngine(Boolean undeployHostedEngine);
     }
@@ -1791,6 +1951,12 @@ public interface HostService extends MeasurableService {
      * registers itself with the engine.
      */
     public interface ApproveUsingSshRequest extends Request<ApproveUsingSshRequest, ApproveUsingSshResponse> {
+        /**
+         * When set to 'true', this host will be activated after its approval completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its approval. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after approval.
+         */
+        ApproveUsingSshRequest activate(Boolean activate);
         /**
          * Indicates if the approval should be performed asynchronously.
          */
@@ -1825,13 +1991,19 @@ public interface HostService extends MeasurableService {
      * password.
      */
     public interface InstallUsingSshRequest extends Request<InstallUsingSshRequest, InstallUsingSshResponse> {
+        /**
+         * When set to 'true', this host will be activated after its installation completes. When set to 'false'
+         * the host will remain in 'maintenance' status after its installation. Absence of this parameter will be
+         * interpreted as 'true', since the desired default behavior is activating the host after install.
+         */
+        InstallUsingSshRequest activate(Boolean activate);
         /**
          * Indicates if the installation should be performed asynchronously.
          */
         InstallUsingSshRequest async(Boolean async);
         /**
-         * When set to `true` it means this host should also deploy the self-hosted engine components. A missing value
-         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will perform no operation in the
+         * When set to `true` this host will also deploy the self-hosted engine components. A missing value
+         * is treated as `true` i.e deploy. Omitting this parameter means `false` and will not perform any operation in the
          * self-hosted engine area.
          */
         InstallUsingSshRequest deployHostedEngine(Boolean deployHostedEngine);
@@ -1846,7 +2018,7 @@ public interface HostService extends MeasurableService {
          */
         InstallUsingSshRequest image(String image);
         /**
-         * The password of of the `root` user, used to connect to the host via SSH.
+         * The password of the `root` user used to connect to the host via SSH.
          */
         InstallUsingSshRequest rootPassword(String rootPassword);
         InstallUsingSshRequest ssh(Ssh ssh);
@@ -1855,9 +2027,9 @@ public interface HostService extends MeasurableService {
          */
         InstallUsingSshRequest ssh(SshBuilder ssh);
         /**
-         * When set to `true` it means this host should un-deploy the self-hosted engine components and this host will
-         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy
-         * Omitting this parameter means `false` and will perform no operation in the self-hosted engine area.
+         * When set to `true` this host will un-deploy the self-hosted engine components, and this host will
+         * not function as part of the High Availability cluster. A missing value is treated as `true` i.e un-deploy.
+         * Omitting this parameter means `false` and will not perform any operation in the self-hosted engine area.
          */
         InstallUsingSshRequest undeployHostedEngine(Boolean undeployHostedEngine);
     }
