@@ -105,6 +105,16 @@ public interface VmService extends MeasurableService {
          * Indicates if the clone should be performed asynchronously.
          */
         CloneRequest async(Boolean async);
+        /**
+         * Use the `discard_snapshots` parameter when the virtual machine should be clone with its
+         * snapshots collapsed. Default is true.
+         */
+        CloneRequest discardSnapshots(Boolean discardSnapshots);
+        CloneRequest storageDomain(StorageDomain storageDomain);
+        /**
+         * The storage domain on which the virtual machines disks will be copied to.
+         */
+        CloneRequest storageDomain(StorageDomainBuilder storageDomain);
         CloneRequest vm(Vm vm);
         CloneRequest vm(VmBuilder vm);
     }
@@ -703,6 +713,13 @@ public interface VmService extends MeasurableService {
          * requires a specific host, the user can specify the host with either an `id` or `name` parameter.
          */
         MigrateRequest host(HostBuilder host);
+        /**
+         * Migrate also all other virtual machines in positive enforcing affinity groups with this virtual machine,
+         * that are running on the same host.
+         * 
+         * The default value is `false`.
+         */
+        MigrateRequest migrateVmsInAffinityClosure(Boolean migrateVmsInAffinityClosure);
     }
     
     /**
@@ -1011,6 +1028,11 @@ public interface VmService extends MeasurableService {
          * Indicates if the shutdown should be performed asynchronously.
          */
         ShutdownRequest async(Boolean async);
+        /**
+         * The reason the virtual machine was stopped.
+         * Optionally set by user when shutting down the virtual machine.
+         */
+        ShutdownRequest reason(String reason);
     }
     
     /**
@@ -1094,6 +1116,19 @@ public interface VmService extends MeasurableService {
          * See https://cloudinit.readthedocs.io/en/latest[this] for details.
          */
         StartRequest useCloudInit(Boolean useCloudInit);
+        /**
+         * If set to `true`, the initialization type is set to _Ignition_. The default value is `false`.
+         * See https://coreos.com/ignition/docs/latest/[this] for details.
+         */
+        StartRequest useIgnition(Boolean useIgnition);
+        /**
+         * If set to `true`, the initialization type is set by the VM's OS.
+         * Windows will set to _Sysprep_, Linux to _cloud-init_ and RedHat CoreOS to _Ignition_.
+         * If any of the initialization-types are explicitly set (useCloudInit, useSysprep or useIgnition),
+         * they will be prioritized and this flag will be ignored.
+         * The default value is `false`.
+         */
+        StartRequest useInitialization(Boolean useInitialization);
         /**
          * If set to `true`, the initialization type is set to _Sysprep_. The default value is `false`.
          * See https://en.wikipedia.org/wiki/Sysprep[this] for details.
@@ -1199,6 +1234,11 @@ public interface VmService extends MeasurableService {
          * Indicates if the stop action should be performed asynchronously.
          */
         StopRequest async(Boolean async);
+        /**
+         * The reason the virtual machine was stopped.
+         * Optionally set by user when shutting down the virtual machine.
+         */
+        StopRequest reason(String reason);
     }
     
     /**
