@@ -38,10 +38,18 @@ import java.util.List;
  */
 public interface Quota extends Identified {
     BigInteger clusterHardLimitPct();
+    Byte clusterHardLimitPctAsByte();
+    Short clusterHardLimitPctAsShort();
+    Integer clusterHardLimitPctAsInteger();
+    Long clusterHardLimitPctAsLong();
     
     boolean clusterHardLimitPctPresent();
     
     BigInteger clusterSoftLimitPct();
+    Byte clusterSoftLimitPctAsByte();
+    Short clusterSoftLimitPctAsShort();
+    Integer clusterSoftLimitPctAsInteger();
+    Long clusterSoftLimitPctAsLong();
     
     boolean clusterSoftLimitPctPresent();
     
@@ -54,10 +62,18 @@ public interface Quota extends Identified {
     boolean disksPresent();
     
     BigInteger storageHardLimitPct();
+    Byte storageHardLimitPctAsByte();
+    Short storageHardLimitPctAsShort();
+    Integer storageHardLimitPctAsInteger();
+    Long storageHardLimitPctAsLong();
     
     boolean storageHardLimitPctPresent();
     
     BigInteger storageSoftLimitPct();
+    Byte storageSoftLimitPctAsByte();
+    Short storageSoftLimitPctAsShort();
+    Integer storageSoftLimitPctAsInteger();
+    Long storageSoftLimitPctAsLong();
     
     boolean storageSoftLimitPctPresent();
     
